@@ -384,38 +384,35 @@ _gdaui_utility_proxy_compute_values_for_group (GdauiSetGroup *group, GdauiDataSt
  * Errors reporting
  */
 static GtkWidget *
-create_data_error_dialog (GdauiDataWidget *form, gboolean with_question, gboolean can_discard, GError *filled_error)
+create_data_error_dialog (GdauiDataProxy *form, gboolean with_question, gboolean can_discard, GError *filled_error)
 {
 	GtkWidget *dlg;
-	gchar *msg;
+	const gchar *msg1 = NULL, *msg2 = NULL;
 
 	if (can_discard) {
+		msg1 = _("Current modified data is invalid");
 		if (with_question)
-			msg = g_strdup_printf ("<b>%s:</b>\n\n%s",
-					       _("Current modified data is invalid"),
-					       _("You may now choose to correct it, or to discard\n"
-						 "the modifications.\n\n"
-						 "What do you wan to do?"));
+			msg2 =_("You may now choose to correct it, or to discard\n"
+				"the modifications.\n\n"
+				"What do you wan to do?");
 		else
-			msg = g_strdup_printf ("<b>%s:</b>\n\n%s",
-					       _("Current modified data is invalid"),
-					       _("please correct it and try again, or discard\n"
-						 "the modifications."));
+			msg2 = _("please correct it and try again, or discard\n"
+				 "the modifications.");
 	}
 	else {
 		if (with_question)
 			g_warning ("Incoherence problem...\n");
-		else
-			msg = g_strdup_printf ("<b>%s:</b>\n\n%s",
-					       _("Part of the current modified data was invalid"),
-					       _("As no transaction was used, only a part of the valid data\n"
-						 "has been written, and the remaining modification have been discarded."));
+		else {
+			msg1 = _("Part of the current modified data was invalid");
+			msg2 = _("As no transaction was used, only a part of the valid data\n"
+				 "has been written, and the remaining modification have been discarded.");
+		}
 	}
-	dlg = gtk_message_dialog_new_with_markup ((GtkWindow *) gtk_widget_get_toplevel (GTK_WIDGET (form)), GTK_DIALOG_MODAL,
+	dlg = gtk_message_dialog_new_with_markup ((GtkWindow *) gtk_widget_get_toplevel (GTK_WIDGET (form)),
+						  GTK_DIALOG_MODAL,
 						  GTK_MESSAGE_ERROR, 
 						  with_question ? GTK_BUTTONS_NONE : GTK_BUTTONS_CLOSE,
-						  "%s", msg);
-	g_free (msg);
+						  "<b>%s:</b>\n\n%s", msg1, msg2);
 
 	if (filled_error && filled_error->message) {
 		GtkWidget *exp, *sw, *view;
@@ -442,7 +439,12 @@ create_data_error_dialog (GdauiDataWidget *form, gboolean with_question, gboolea
 		
 		gtk_container_add (GTK_CONTAINER (sw), view);
 		gtk_container_add (GTK_CONTAINER (exp), sw);
+#if GTK_CHECK_VERSION(2,18,0)
+		gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dlg))),
+				    exp, TRUE, TRUE, 0);
+#else
 		gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dlg)->vbox), exp, TRUE, TRUE, 0);
+#endif
 		gtk_widget_show_all (exp);
 
 		gtk_window_set_resizable (GTK_WINDOW (dlg), TRUE);
@@ -462,7 +464,7 @@ create_data_error_dialog (GdauiDataWidget *form, gboolean with_question, gboolea
  * Returns: TRUE if current data can be discarded
  */
 gboolean
-_gdaui_utility_display_error_with_keep_or_discard_choice (GdauiDataWidget *form, GError *filled_error)
+_gdaui_utility_display_error_with_keep_or_discard_choice (GdauiDataProxy *form, GError *filled_error)
 {
 	GtkWidget *dlg;
 	gint res;
@@ -489,7 +491,7 @@ _gdaui_utility_display_error_with_keep_or_discard_choice (GdauiDataWidget *form,
  * led to the error.
  */
 void
-_gdaui_utility_display_error (GdauiDataWidget *form, gboolean can_discard, GError *filled_error)
+_gdaui_utility_display_error (GdauiDataProxy *form, gboolean can_discard, GError *filled_error)
 {
 	GtkWidget *dlg;
 	
